package com.ruoyi.ibs.grid.mapper;

import java.util.HashMap;
import java.util.List;

import com.ruoyi.ibs.grid.domain.entity.GridVirtualCountGongsi;
import com.ruoyi.ibs.grid.domain.entity.GridVirtualCountLingshou;
import com.ruoyi.ibs.grid.domain.entity.GridVirtualCustGongsi;
import com.ruoyi.ibs.grid.domain.entity.GridVirtualCustLingshou;
import org.springframework.stereotype.Repository;

/**
 * 虚拟网格汇总统计_Mapper接口
 * 
 * @author ruoyi
 * @date 2025-04-24
 */
@Repository
public interface GridVirtualCountMapper 
{
    /**
     * 查询虚拟网格汇总统计_零售
     * 
     * @param dt 虚拟网格汇总统计_零售主键
     * @return 虚拟网格汇总统计_零售
     */
    public GridVirtualCountLingshou selectGridVirtualCountLingshouByDt(String dt);

    /**
     * 查询虚拟网格汇总统计_零售列表
     */
    public List<GridVirtualCountLingshou> selectGridVirtualCountLingshouList(HashMap<String, Object> paramMap);

    public List<GridVirtualCountGongsi> selectGridVirtualCountGongsiList(HashMap<String, Object> paramMap);

    public List<GridVirtualCustGongsi> selectGridVirtualCountgsCustList(HashMap<String, Object> paramMap);

    public List<GridVirtualCustLingshou> selectGridVirtualCountlsCustList(HashMap<String, Object> paramMap);

    /**
     * 新增虚拟网格汇总统计_零售
     * 
     * @param GridVirtualCountLingshou 虚拟网格汇总统计_零售
     * @return 结果
     */
    public int insertGridVirtualCountLingshou(GridVirtualCountLingshou GridVirtualCountLingshou);

    /**
     * 修改虚拟网格汇总统计_零售
     * 
     * @param GridVirtualCountLingshou 虚拟网格汇总统计_零售
     * @return 结果
     */
    public int updateGridVirtualCountLingshou(GridVirtualCountLingshou GridVirtualCountLingshou);

    /**
     * 删除虚拟网格汇总统计_零售
     * 
     * @param dt 虚拟网格汇总统计_零售主键
     * @return 结果
     */
    public int deleteGridVirtualCountLingshouByDt(String dt);

    /**
     * 批量删除虚拟网格汇总统计_零售
     * 
     * @param dts 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGridVirtualCountLingshouByDts(String[] dts);
}
